#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 attoparsec-aeson
version:              2.2.0.1
visibility:           public
id:                   attoparsec-aeson-2.2.0.1-5ktf0yigd81HUMzMkrymWl
key:                  attoparsec-aeson-2.2.0.1-5ktf0yigd81HUMzMkrymWl
license:              BSD-3-Clause
copyright:
    (c) 2011-2016 Bryan O'\''Sullivan
    (c) 2011 MailRank, Inc.

maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:               Bryan O'\''Sullivan <bos@serpentine.com>
stability:            experimental
homepage:             https://github.com/haskell/aeson
synopsis:             Parsing of aeson'\''s Value with attoparsec
description:
    Parsing of aeson'\''s Value with attoparsec, originally from aeson.

category:             Parsing
abi:                  5aba1b377767e9c21aab0cd8849fe680
exposed:              True
exposed-modules:      Data.Aeson.Parser Data.Aeson.Parser.Internal
hidden-modules:
    Data.Aeson.Internal.ByteString Data.Aeson.Internal.Text
    Data.Aeson.Internal.Word8

import-dirs:          /usr/lib/ghc-9.6.6/site-local/attoparsec-aeson-2.2.0.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/attoparsec-aeson-2.2.0.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/attoparsec-aeson-2.2.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-attoparsec-aeson
hs-libraries:         HSattoparsec-aeson-2.2.0.1-5ktf0yigd81HUMzMkrymWl
depends:
    aeson-2.2.2.0-CuqyF0GV84l91XsdnO7HOm
    attoparsec-0.14.4-GluE1clWXeWeSjHE1bFts base-4.18.2.1
    bytestring-0.11.5.3 integer-conversion-0.1.1-ykZX5KJSzaA7K0I28boqW
    primitive-0.9.1.0-9h2EHc8o8mEoP1C086uNV
    scientific-0.3.8.1-Co1OoXRAd2pL4XpBjX62A7 text-2.0.2
    vector-0.13.2.0-KHhvLzyWGFJKP6boEp8Bp2

haddock-interfaces:
    /usr/share/doc/haskell-attoparsec-aeson/html/attoparsec-aeson.haddock

haddock-html:         /usr/share/doc/haskell-attoparsec-aeson/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

